@@ -7,6 +7,7 @@ import re
 import sys
 
 from dateutil import tz
+from dateutil import parser
 from rich.console import Console
 from rich.table import Table
 
@@ -291,27 +292,58 @@ class QA:
 
         # Check if instance status is still pending
         if response["list"] and response["list"]["status"] in ["creating", "updating"]:
+            microservices = self._filter_list(
+                "type", ["microservice"], response["list"]["resources"]
+            )
             # 1. Microservices list is empty?
-            if len(response["list"]["resources"]) == 0:
+            if len(microservices) == 0:
                 issues.append("Microservices list is empty, please be patient.")
+                return issues
 
-            # 2. Check every resource
+            # 2. Check if qainit worker is still launching updates
+            if not self._is_update_initiated(microservices, response["list"]):
+                issues.append(
+                    "Qainit is still working on microservices, try again in a while."
+                )
+                issues.append("https://www.youtube.com/watch?v=0ASiDR5Yj0k")
+                return issues
+
+            # 3. Check every resource
             stale_resources = self._filter_list(
-                "status", ["creating", "updating"], response["list"]["resources"]
+                "status", ["creating", "updating"], microservices
             )
             for resource in stale_resources:
                 issues += self._check_resource_issues(resource)
 
-            # 3. Check is instance is stuck in a stale status
-            # if len(stale_resources) == 0:
-            #     logger.warning("Trying to call qainit to force QA update...")
-            #     self._qainit.force_update(response["list"]["hash"])
-            #     issues.append(
-            #         "Your QA was in a stale status and has been fixed, launch `suite-py describe` again please."
-            #     )
+            # 4. Check is instance is stuck in a stale status
+            if (
+                len(microservices) > 0
+                and len(stale_resources) == 0
+                and self._minutes_elapsed_since_update(response["list"]) >= 5
+            ):
+                logger.warning("Trying to call qainit to force QA update...")
+                self._qainit.force_update(response["list"]["hash"])
+                issues.append(
+                    "Your QA was in a stale status and has been fixed, launch `suite-py describe` again please."
+                )
 
         return issues
 
+    def _is_update_initiated(self, microservices, instance):
+        microservices_updates = [
+            parser.parse(x["updated_at"]).timestamp() for x in microservices
+        ]
+        max_microservice_update = max(microservices_updates)
+        instance_update = parser.parse(instance["updated_at"]).timestamp()
+
+        return max_microservice_update >= instance_update
+
+    def _minutes_elapsed_since_update(self, instance):
+        return (
+            datetime.datetime.now().timestamp()
+            - parser.parse(instance["updated_at"]).timestamp()
+        ) / 60
+
     def _check_resource_issues(self, resource):
         issues = []
 
